(setf *tries* 2)
(setf *reminder* 5)

(alert notification "echo '%state% %function% %params% %result% %date%'")

;; check for /tmp/ disk usage
;; create a big file to increase size
(=> notification disk-usage :path "/tmp" :limit 5 :reminder 2)
(=> notification disk-usage :path "/"    :limit 1 :reminder 2)
(=> notification disk-usage :path "/"    :limit 1 :reminder 2)
(=> notification disk-usage :path "/"    :limit 1 :reminder 2)
(=> notification disk-usage :path "/"    :limit 1 :reminder 2)
(=> notification disk-usage :path "/"    :limit 1 :reminder 2)
(=> notification disk-usage :path "/"    :limit 1 :reminder 2)

(and
 (=> notification disk-usage :path "/"    :limit 99 :reminder 2 :desc "always OK")
 (=> notification disk-usage :path "/"    :limit 1 :reminder 2 :desc "always error")
 (=> notification disk-usage :path "/"    :limit 1 :reminder 2 :desc "always error, should not be displayed"))


(or
 (=> notification disk-usage :path "/"    :limit 1 :reminder 2 :desc "always error, should be followed by always ok")
 (=> notification disk-usage :path "/"    :limit 99 :reminder 2 :desc "always OK"))

(=> notification write-to-file :path "/tmp/hello.txt")
(=> notification write-to-file :path "/tmp/hello2.txt" :text "hi")
